@@ -28,9 +28,13 @@ Na Windows take budete muset nainstalovat Pywin32 [4].
 Pokud chcete z jakéhokoliv důvodu přeskočit kontrolování závislostí, můžete
 použít parametr --skip-deps.
 
-[1]: http://wxpython.org/ [2]: http://code.google.com/p/pybluez/ [3]:
-http://www.freedesktop.org/wiki/Software/DBusBindings [4]:
-https://sourceforge.net/projects/pywin32/
+[1]: http://wxpython.org/
+
+[2]: http://code.google.com/p/pybluez/
+
+[3]: http://www.freedesktop.org/wiki/Software/DBusBindings
+
+[4]: https://sourceforge.net/projects/pywin32/
 
 
 Křížová kompilace pro Windows na Linuxu
@@ -57,7 +61,9 @@ Poté můžete použít InnoSetup[6] pro vytvoření instalátoru Wammu:
 
     wine c:\\Program\ Files\\Inno\ Setup\ 5/\\ISCC.exe wammu.iss
 
-[5]: http://www.py2exe.org/ [6]: http://www.jrsoftware.org/isinfo.php
+[5]: http://www.py2exe.org/
+
+[6]: http://www.jrsoftware.org/isinfo.php
 
 [w1]: http://bugs.winehq.org/show_bug.cgi?id=3591
 
