@@ -632,7 +632,26 @@ MAC_Prefixes = {
             '00:1C:A4',
             '00:1D:28',
             '00:1E:45',
+            '00:1E:DC',
+            '00:1F:E4',
+            '00:21:9E',
+            '00:22:98',
+            '00:23:45',
+            '00:23:F1',
+            '00:24:EF',
+            '00:25:E7',
             '00:80:37',
+            '24:21:AB',
+            '30:17:C8',
+            '40:2B:A1',
+            '58:17:0C',
+            '6C:0E:0D',
+            '6C:23:B9',
+            '90:55:AE',
+            'B4:0E:DC',
+            'B8:F9:34',
+            'C8:35:B8',
+            'D0:F0:DB',
             ],
         'Nokia' : [
             '00:02:EE',
@@ -679,9 +698,64 @@ MAC_Prefixes = {
             '00:1E:3B',
             '00:1E:A3',
             '00:1E:A4',
+            '00:1F:00',
+            '00:1F:01',
+            '00:1F:5C',
+            '00:1F:5D',
+            '00:1F:DE',
+            '00:1F:DF',
+            '00:21:08',
+            '00:21:09',
+            '00:21:AA',
+            '00:21:AB',
+            '00:21:FC',
+            '00:21:FE',
+            '00:22:65',
+            '00:22:66',
+            '00:22:FC',
+            '00:22:FD',
+            '00:23:B4',
+            '00:24:03',
+            '00:24:04',
+            '00:24:7C',
+            '00:24:7D',
+            '00:25:47',
+            '00:25:48',
+            '00:25:CF',
+            '00:25:D0',
+            '00:26:68',
+            '00:26:69',
+            '00:26:CC',
             '00:40:43',
             '00:A0:8E',
+            '00:BD:3A',
             '00:E0:03',
+            '0C:DD:EF',
+            '18:14:56',
+            '18:86:AC',
+            '20:D6:07',
+            '2C:D2:E7',
+            '30:38:55',
+            '34:7E:39',
+            '3C:F7:2A',
+            '5C:57:C8',
+            '6C:9B:02',
+            '80:50:1B',
+            '94:20:53',
+            '9C:18:74',
+            '9C:4A:7B',
+            'A0:4E:04',
+            'A8:7B:39',
+            'A8:7E:33',
+            'C0:38:F9',
+            'C8:97:9F',
+            'C8:DF:7C',
+            'D4:CB:AF',
+            'D8:75:33',
+            'E0:A6:70',
+            'E4:EC:10',
+            'EC:9B:5B',
+            'FC:E5:57',
             ],
         'Siemens' : [
             '00:01:E3',
@@ -694,18 +768,23 @@ MAC_Prefixes = {
             '00:11:06',
             '00:11:33',
             '00:13:A3',
+            '00:18:65',
             '00:18:D1',
             '00:19:28',
-            '00:19:99',
-            '00:1A:D0',
             '00:1A:E8',
             '00:1B:1B',
             '00:1C:06',
+            '00:1F:F8',
+            '00:23:41',
             '00:30:05',
+            '00:40:43',
             '00:50:07',
             '00:90:40',
+            '00:A0:03',
             '00:C0:E4',
             '08:00:06',
+            '40:EC:F8',
+            '88:4B:39',
             ],
         'Samsung' : [
             '00:00:F0',
@@ -713,7 +792,6 @@ MAC_Prefixes = {
             '00:09:18',
             '00:0D:AE',
             '00:0D:E5',
-            '00:0F:73',
             '00:12:47',
             '00:12:FB',
             '00:13:77',
@@ -732,26 +810,80 @@ MAC_Prefixes = {
             '00:1D:25',
             '00:1D:F6',
             '00:1E:7D',
+            '00:1E:E1',
+            '00:1E:E2',
+            '00:1F:CC',
+            '00:1F:CD',
+            '00:21:19',
+            '00:21:4C',
+            '00:21:D1',
+            '00:21:D2',
+            '00:23:39',
+            '00:23:3A',
+            '00:23:99',
+            '00:23:C2',
+            '00:23:D6',
+            '00:23:D7',
+            '00:24:54',
+            '00:24:90',
+            '00:24:91',
+            '00:24:E9',
+            '00:25:38',
+            '00:25:66',
+            '00:25:67',
+            '00:26:37',
+            '00:26:5D',
+            '00:26:5F',
             '00:E0:64',
+            '10:1D:C0',
+            '34:C3:AC',
+            '38:01:97',
+            '3C:8B:FE',
+            '44:4E:1A',
+            '44:F4:59',
+            '54:92:BE',
+            '60:A1:0A',
+            '60:D0:A9',
+            '68:EB:AE',
+            '78:25:AD',
+            'A0:07:98',
+            'A0:0B:BA',
+            'A8:F2:74',
+            'B4:07:F9',
+            'BC:47:60',
+            'C8:7E:75',
+            'D4:88:90',
+            'D4:E8:B2',
+            'E4:7C:F9',
+            'E4:E0:C5',
+            'E8:11:32',
+            'E8:E5:D6',
+            'EC:E0:9B',
+            'F4:9F:54',
+            'FC:A1:3E',
             ],
         'LG' : [
-            '00:05:C9',
-            '00:0B:29',
-            '00:12:56',
-            '00:14:80',
-            '00:19:A1',
             '00:1C:62',
             '00:1E:75',
-            '00:1E:B2',
-            '00:50:CE',
+            '00:1F:6B',
+            '00:1F:E3',
+            '00:21:FB',
+            '00:22:A9',
+            '00:24:83',
+            '00:25:E5',
+            '00:26:E2',
             '00:E0:91',
+            '20:21:A5',
+            '6C:D6:8A',
+            'E8:5B:5B',
             ],
         'BenQ' : [
             '00:03:9D',
             '00:17:CA',
+            '00:1E:21',
             ],
         'Motorola' : [
-            '00:01:AF',
+            '00:03:E0',
             '00:04:56',
             '00:04:BD',
             '00:08:0E',
@@ -772,6 +904,7 @@ MAC_Prefixes = {
             '00:14:9A',
             '00:14:E8',
             '00:15:2F',
+            '00:15:70',
             '00:15:9A',
             '00:15:A8',
             '00:16:26',
@@ -804,11 +937,58 @@ MAC_Prefixes = {
             '00:1E:46',
             '00:1E:5A',
             '00:1E:8D',
+            '00:1F:7E',
+            '00:1F:C4',
             '00:20:40',
             '00:20:75',
+            '00:21:1E',
+            '00:21:36',
+            '00:21:43',
+            '00:21:80',
+            '00:22:10',
+            '00:22:B4',
+            '00:23:0B',
+            '00:23:68',
+            '00:23:74',
+            '00:23:75',
+            '00:23:95',
+            '00:23:A2',
+            '00:23:A3',
+            '00:23:AF',
+            '00:23:ED',
+            '00:23:EE',
+            '00:24:37',
+            '00:24:92',
+            '00:24:93',
+            '00:24:95',
+            '00:24:A0',
+            '00:24:A1',
+            '00:24:C1',
+            '00:25:F1',
+            '00:25:F2',
+            '00:26:36',
+            '00:26:41',
+            '00:26:42',
+            '00:26:BA',
+            '00:50:E3',
+            '00:90:9C',
             '00:A0:BF',
-            '00:C0:F9',
+            '00:D0:88',
             '00:E0:0C',
+            '00:E0:6F',
+            '2C:9E:5F',
+            '3C:75:4A',
+            '40:83:DE',
+            '40:FC:89',
+            '48:2C:EA',
+            '5C:0E:8B',
+            '64:ED:57',
+            '74:E7:C6',
+            '74:F6:12',
+            'A4:ED:4E',
+            'E4:64:49',
+            'E4:83:99',
+            'F8:7B:7A',
             ],
         'Alcatel' : [
             '00:07:72',
@@ -827,6 +1007,11 @@ MAC_Prefixes = {
             '00:20:32',
             '00:20:60',
             '00:20:DA',
+            '00:21:05',
+            '00:21:35',
+            '00:21:AE',
+            '00:23:3E',
+            '00:25:BA',
             '00:80:21',
             '00:80:39',
             '00:80:9F',
@@ -836,6 +1021,17 @@ MAC_Prefixes = {
             '00:D0:F6',
             '00:E0:B1',
             '00:E0:DA',
+            '0C:A4:02',
+            '18:42:2F',
+            '18:80:F5',
+            '24:AF:4A',
+            '38:52:1A',
+            '48:F8:E1',
+            '68:59:7F',
+            '6C:BE:E9',
+            '7C:20:64',
+            '8C:90:D3',
+            '90:67:B5',
             ],
         }
 
