@@ -909,8 +909,12 @@ class WammuFrame(wx.Frame):
         self.Destroy()
 
     def ShowError(self, info):
+        try:
+            gammu_config = self.gammu_config
+        except AttributeError:
+            gammu_config = Noe
         evt = Wammu.Events.ShowMessageEvent(
-            message = Wammu.Utils.FormatError(_('Error while communicating with phone'), info),
+            message = Wammu.Utils.FormatError(_('Error while communicating with phone'), info, gammu_config = gammu_config),
             title = _('Error Occured'),
             errortype = 'gammu',
             type = wx.ICON_ERROR)
@@ -1259,6 +1263,8 @@ class WammuFrame(wx.Frame):
             return
         if self.type[0] == 'contact':
             self.EditContact(evt.data)
+        elif self.type[0] == 'call' and evt.data['Location'] == 0:
+            self.EditContact(evt.data)
         elif self.type[0] == 'calendar':
             self.EditCalendar(evt.data)
         elif self.type[0] == 'todo':
@@ -2096,6 +2102,9 @@ class WammuFrame(wx.Frame):
             'Model': config['Model'],
             }
 
+        # Store configuration for error handling
+        self.gammu_config = cfg
+
         # Compatibility with old Gammu versions
         cfg = Wammu.Utils.CompatConfig(cfg)
 
